==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebDensityChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDensityChangedEventArgsDetailDescriptionMetadata } from "./WebDensityChangedEventArgsDetailDescriptionMetadata";
import { WebDensityChangedEventArgsDescription } from "./WebDensityChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebDensityChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDensityChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebDensityChangedEventArgsDescriptionMetadata.a == null) {
                WebDensityChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDensityChangedEventArgsDescriptionMetadata.c(WebDensityChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebDensityChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebDensityChangedEventArgsDescriptionMetadata.a);
            WebDensityChangedEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DensityChangedEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebDensityChangedEventArgsDetail");
        }
        static d(a) {
            WebDensityChangedEventArgsDescriptionMetadata.b(a);
            a.aa("WebDensityChangedEventArgs", () => new WebDensityChangedEventArgsDescription());
            a.z("WebDensityChangedEventArgs", WebDensityChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebDensityChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDensityChangedEventArgsDescriptionMetadata, 'WebDensityChangedEventArgsDescriptionMetadata');
    WebDensityChangedEventArgsDescriptionMetadata.a = null;
    return WebDensityChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebDensityChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDensityChangedEventArgsDetailDescriptionMetadata } from "./WebDensityChangedEventArgsDetailDescriptionMetadata";
import { WebDensityChangedEventArgsDescription } from "./WebDensityChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebDensityChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDensityChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebDensityChangedEventArgsDescriptionMetadata.a == null) {
                WebDensityChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDensityChangedEventArgsDescriptionMetadata.c(WebDensityChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebDensityChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDensityChangedEventArgsDescriptionMetadata.a);
            WebDensityChangedEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DensityChangedEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebDensityChangedEventArgsDetail");
        }
        static d(a) {
            WebDensityChangedEventArgsDescriptionMetadata.b(a);
            a.ac("WebDensityChangedEventArgs", () => new WebDensityChangedEventArgsDescription());
            a.ab("WebDensityChangedEventArgs", WebDensityChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebDensityChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDensityChangedEventArgsDescriptionMetadata, 'WebDensityChangedEventArgsDescriptionMetadata');
    WebDensityChangedEventArgsDescriptionMetadata.a = null;
    return WebDensityChangedEventArgsDescriptionMetadata;
})();
